@@ -2,7 +2,7 @@
  *
  * This file is part of Mapnik (c++ mapping toolkit)
  *
- * Copyright (C) 2024 Artem Pavlenko
+ * Copyright (C) 2025 Artem Pavlenko
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -65,9 +65,9 @@ struct layer_rendering_material
     std::vector<layer_rendering_material> materials_;
 
     layer_rendering_material(layer const& lay, projection const& dest)
-        : lay_(lay)
-        , proj0_(dest)
-        , proj1_(lay.srs(), true)
+        : lay_(lay),
+          proj0_(dest),
+          proj1_(lay.srs(), true)
     {}
 
     layer_rendering_material(layer_rendering_material&& rhs) = default;
@@ -248,7 +248,7 @@ void feature_style_processor<Processor>::prepare_layer(layer_rendering_material&
     box2d<double> buffered_query_ext(query_ext); // buffered
 
     double buffer_padding = 2.0 * scale * p.scale_factor();
-    const auto layer_buffer_size = lay.buffer_size();
+    auto const layer_buffer_size = lay.buffer_size();
     if (layer_buffer_size) // if layer overrides buffer size, use this value to compute buffered extent
     {
         buffer_padding *= *layer_buffer_size;
@@ -268,7 +268,7 @@ void feature_style_processor<Processor>::prepare_layer(layer_rendering_material&
     }
 
     box2d<double> layer_ext = lay.envelope();
-    const box2d<double> buffered_query_ext_map_srs = buffered_query_ext;
+    box2d<double> const buffered_query_ext_map_srs = buffered_query_ext;
     bool fw_success = false;
     bool early_return = false;
 
@@ -418,12 +418,17 @@ void feature_style_processor<Processor>::prepare_layer(layer_rendering_material&
     }
     q.set_filter_factor(collector.get_filter_factor());
 
-    // Also query the group by attribute
+    // Also query the group-by and sort-by attribute
     std::string const& group_by = lay.group_by();
     if (!group_by.empty())
     {
         q.add_property_name(group_by);
     }
+    auto sort_by = lay.sort_by();
+    if (sort_by)
+    {
+        q.add_property_name((*sort_by).first);
+    }
 
     bool cache_features = lay.cache_features() && active_styles.size() > 1;
 
@@ -482,11 +487,34 @@ void feature_style_processor<Processor>::render_material(layer_rendering_materia
     bool cache_features = lay.cache_features() && active_styles.size() > 1;
 
     datasource_ptr ds = lay.datasource();
+
+    auto sort_by = lay.sort_by();
     std::string group_by = lay.group_by();
 
-    // Render incrementally when the column that we group by changes value.
-    if (!group_by.empty())
+    if (sort_by) // sort features
     {
+        featureset_ptr features = *featureset_ptr_list.begin();
+        if (features)
+        {
+            std::shared_ptr<featureset_buffer> cache = std::make_shared<featureset_buffer>();
+            feature_ptr feature;
+            while ((feature = features->next()))
+            {
+                cache->push(feature);
+            }
+            cache->sort_by((*sort_by).first, (*sort_by).second);
+            std::size_t i = 0;
+            for (feature_type_style const* style : active_styles)
+            {
+                cache->prepare();
+                render_style(p, style, rule_caches[i++], cache, *proj_trans_ptr);
+            }
+            // cache->clear();
+        }
+    }
+    else if (!group_by.empty())
+    {
+        // Render incrementally when the column that we group by changes value.
         featureset_ptr features = *featureset_ptr_list.begin();
         if (features)
         {
