@@ -2,7 +2,7 @@
  *
  * This file is part of Mapnik (c++ mapping toolkit)
  *
- * Copyright (C) 2024 Artem Pavlenko
+ * Copyright (C) 2025 Artem Pavlenko
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -44,28 +44,28 @@ struct gray16
 
     //--------------------------------------------------------------------
     gray16(unsigned v_, unsigned a_ = base_mask)
-        : v(agg::int16u(v_))
-        , a(agg::int16u(a_))
+        : v(agg::int16u(v_)),
+          a(agg::int16u(a_))
     {}
 
     //--------------------------------------------------------------------
-    gray16(const self_type& c, unsigned a_)
-        : v(c.v)
-        , a(value_type(a_))
+    gray16(self_type const& c, unsigned a_)
+        : v(c.v),
+          a(value_type(a_))
     {}
 
     //--------------------------------------------------------------------
     void clear() { v = a = 0; }
 
     //--------------------------------------------------------------------
-    const self_type& transparent()
+    self_type const& transparent()
     {
         a = 0;
         return *this;
     }
 
     //--------------------------------------------------------------------
-    const self_type& premultiply()
+    self_type const& premultiply()
     {
         if (a == base_mask)
             return *this;
@@ -79,7 +79,7 @@ struct gray16
     }
 
     //--------------------------------------------------------------------
-    const self_type& premultiply(unsigned a_)
+    self_type const& premultiply(unsigned a_)
     {
         if (a == base_mask && a_ >= base_mask)
             return *this;
@@ -95,7 +95,7 @@ struct gray16
     }
 
     //--------------------------------------------------------------------
-    const self_type& demultiply()
+    self_type const& demultiply()
     {
         if (a == base_mask)
             return *this;
@@ -120,7 +120,7 @@ struct gray16
     }
 
     //--------------------------------------------------------------------
-    AGG_INLINE void add(const self_type& c, unsigned cover)
+    AGG_INLINE void add(self_type const& c, unsigned cover)
     {
         calc_type cv, ca;
         if (cover == agg::cover_mask)
@@ -172,28 +172,28 @@ struct gray32
 
     //--------------------------------------------------------------------
     gray32(value_type v_, unsigned a_ = base_mask)
-        : v(v_)
-        , a(value_type(a_))
+        : v(v_),
+          a(value_type(a_))
     {}
 
     //--------------------------------------------------------------------
-    gray32(const self_type& c, unsigned a_)
-        : v(c.v)
-        , a(value_type(a_))
+    gray32(self_type const& c, unsigned a_)
+        : v(c.v),
+          a(value_type(a_))
     {}
 
     //--------------------------------------------------------------------
     void clear() { v = a = 0; }
 
     //--------------------------------------------------------------------
-    const self_type& transparent()
+    self_type const& transparent()
     {
         a = 0;
         return *this;
     }
 
     //--------------------------------------------------------------------
-    const self_type& premultiply()
+    self_type const& premultiply()
     {
         if (a == base_mask)
             return *this;
@@ -207,7 +207,7 @@ struct gray32
     }
 
     //--------------------------------------------------------------------
-    const self_type& premultiply(unsigned a_)
+    self_type const& premultiply(unsigned a_)
     {
         if (a == base_mask && a_ >= base_mask)
             return *this;
@@ -223,7 +223,7 @@ struct gray32
     }
 
     //--------------------------------------------------------------------
-    const self_type& demultiply()
+    self_type const& demultiply()
     {
         if (a == base_mask)
             return *this;
@@ -248,7 +248,7 @@ struct gray32
     }
 
     //--------------------------------------------------------------------
-    AGG_INLINE void add(const self_type& c, unsigned cover)
+    AGG_INLINE void add(self_type const& c, unsigned cover)
     {
         calc_type cv, ca;
         if (cover == agg::cover_mask)
@@ -300,28 +300,28 @@ struct gray64
 
     //--------------------------------------------------------------------
     gray64(value_type v_, unsigned a_ = base_mask)
-        : v(v_)
-        , a(value_type(a_))
+        : v(v_),
+          a(value_type(a_))
     {}
 
     //--------------------------------------------------------------------
-    gray64(const self_type& c, unsigned a_)
-        : v(c.v)
-        , a(value_type(a_))
+    gray64(self_type const& c, unsigned a_)
+        : v(c.v),
+          a(value_type(a_))
     {}
 
     //--------------------------------------------------------------------
     void clear() { v = a = 0; }
 
     //--------------------------------------------------------------------
-    const self_type& transparent()
+    self_type const& transparent()
     {
         a = 0;
         return *this;
     }
 
     //--------------------------------------------------------------------
-    const self_type& premultiply()
+    self_type const& premultiply()
     {
         if (a == base_mask)
             return *this;
@@ -335,7 +335,7 @@ struct gray64
     }
 
     //--------------------------------------------------------------------
-    const self_type& premultiply(unsigned a_)
+    self_type const& premultiply(unsigned a_)
     {
         if (a == base_mask && a_ >= base_mask)
             return *this;
@@ -351,7 +351,7 @@ struct gray64
     }
 
     //--------------------------------------------------------------------
-    const self_type& demultiply()
+    self_type const& demultiply()
     {
         if (a == base_mask)
             return *this;
@@ -376,7 +376,7 @@ struct gray64
     }
 
     //--------------------------------------------------------------------
-    AGG_INLINE void add(const self_type& c, unsigned cover)
+    AGG_INLINE void add(self_type const& c, unsigned cover)
     {
         calc_type cv, ca;
         if (cover == agg::cover_mask)
