@@ -2,7 +2,7 @@
  *
  * This file is part of Mapnik (c++ mapping toolkit)
  *
- * Copyright (C) 2024 Artem Pavlenko
+ * Copyright (C) 2025 Artem Pavlenko
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -45,8 +45,8 @@ class group_symbolizer_helper : public base_symbolizer_helper
     struct box_element
     {
         box_element(box2d<double> const& box, value_unicode_string const& repeat_key = "")
-            : box_(box)
-            , repeat_key_(repeat_key)
+            : box_(box),
+              repeat_key_(repeat_key)
         {}
         box2d<double> box_;
         value_unicode_string repeat_key_;
