@@ -36,16 +36,14 @@
 geojson_memory_index_featureset::geojson_memory_index_featureset(std::string const& filename, array_type&& index_array)
     :
 #ifdef _WIN32
-    file_(_wfopen(mapnik::utf8_to_utf16(filename).c_str(), L"rb"), std::fclose)
-    ,
+      file_(_wfopen(mapnik::utf8_to_utf16(filename).c_str(), L"rb"), std::fclose),
 #else
-    file_(std::fopen(filename.c_str(), "rb"), std::fclose)
-    ,
+      file_(std::fopen(filename.c_str(), "rb"), std::fclose),
 #endif
-    index_array_(std::move(index_array))
-    , index_itr_(index_array_.begin())
-    , index_end_(index_array_.end())
-    , ctx_(std::make_shared<mapnik::context_type>())
+      index_array_(std::move(index_array)),
+      index_itr_(index_array_.begin()),
+      index_end_(index_array_.end()),
+      ctx_(std::make_shared<mapnik::context_type>())
 {
     if (!file_)
         throw std::runtime_error("Can't open " + filename);
@@ -67,7 +65,7 @@ mapnik::feature_ptr geojson_memory_index_featureset::next()
         using chr_iterator_type = char const*;
         chr_iterator_type start = json.data();
         chr_iterator_type end = (count == 1) ? start + json.size() : start;
-        static const mapnik::transcoder tr("utf8");
+        static mapnik::transcoder const tr("utf8");
         mapnik::feature_ptr feature(mapnik::feature_factory::create(ctx_, feature_id_++));
         mapnik::json::parse_feature(start, end, *feature, tr); // throw on failure
         // skip empty geometries
