@@ -62,7 +62,7 @@ class pgraster_featureset : public mapnik::Featureset
   private:
     std::shared_ptr<IResultSet> rs_;
     context_ptr ctx_;
-    const std::unique_ptr<mapnik::transcoder> tr_;
+    std::unique_ptr<mapnik::transcoder> const tr_;
     mapnik::value_integer feature_id_;
     bool key_field_;
     int band_;
