@@ -51,9 +51,9 @@ struct _mapnik_lib_t
     std::string error_str;
     handle dl;
     _mapnik_lib_t()
-        : name{"unknown"}
-        , error_str{""}
-        , dl{nullptr}
+        : name{"unknown"},
+          error_str{""},
+          dl{nullptr}
     {}
     ~_mapnik_lib_t()
     {
@@ -83,8 +83,8 @@ struct _mapnik_lib_t
 };
 
 PluginInfo::PluginInfo(std::string const& filename, std::string const& library_name)
-    : filename_(filename)
-    , module_{std::make_unique<mapnik_lib_t>()}
+    : filename_(filename),
+      module_{std::make_unique<mapnik_lib_t>()}
 {
     assert(module_ != nullptr);
 #if defined(_WIN32)
@@ -106,7 +106,7 @@ PluginInfo::PluginInfo(std::string const& filename, std::string const& library_n
     }
     else
     {
-        const auto errcode = dlerror();
+        auto const errcode = dlerror();
 #ifdef _WIN32
         module_->error_str = std::system_category().message(errcode);
 #else
@@ -121,7 +121,7 @@ PluginInfo::~PluginInfo() {}
 void* PluginInfo::get_symbol(std::string const& sym_name) const
 {
 #ifdef MAPNIK_SUPPORTS_DLOPEN
-    return static_cast<void*>(dlsym(module_->dl, sym_name.c_str()));
+    return reinterpret_cast<void*>(dlsym(module_->dl, sym_name.c_str()));
 #else
     return nullptr;
 #endif
