@@ -135,9 +135,9 @@ class serialize_symbolizer_property
 {
   public:
     serialize_symbolizer_property(Meta const& meta, boost::property_tree::ptree& node, bool explicit_defaults)
-        : meta_(meta)
-        , node_(node)
-        , explicit_defaults_(explicit_defaults)
+        : meta_(meta),
+          node_(node),
+          explicit_defaults_(explicit_defaults)
     {}
 
     void operator()(mapnik::enumeration_wrapper const& e) const
@@ -225,8 +225,8 @@ class serialize_symbolizer
 {
   public:
     serialize_symbolizer(ptree& r, bool explicit_defaults)
-        : rule_(r)
-        , explicit_defaults_(explicit_defaults)
+        : rule_(r),
+          explicit_defaults_(explicit_defaults)
     {}
 
     template<typename Symbolizer>
@@ -255,8 +255,8 @@ class serialize_group_layout
 {
   public:
     serialize_group_layout(ptree& parent_node, bool explicit_defaults)
-        : parent_node_(parent_node)
-        , explicit_defaults_(explicit_defaults)
+        : parent_node_(parent_node),
+          explicit_defaults_(explicit_defaults)
     {}
 
     void operator()(simple_row_layout const& layout) const
@@ -294,7 +294,7 @@ class serialize_group_layout
     bool explicit_defaults_;
 };
 
-void serialize_group_rule(ptree& parent_node, const group_rule& r, bool explicit_defaults)
+void serialize_group_rule(ptree& parent_node, group_rule const& r, bool explicit_defaults)
 {
     ptree& rule_node = parent_node.push_back(ptree::value_type("GroupRule", ptree()))->second;
 
@@ -547,6 +547,15 @@ void serialize_layer(ptree& map_node, layer const& lyr, bool explicit_defaults)
         set_attr(layer_node, "group-by", lyr.group_by());
     }
 
+    if (lyr.sort_by() || explicit_defaults)
+    {
+        auto sort_by = *lyr.sort_by();
+        std::string str = sort_by.first;
+        if (sort_by.second)
+            str += " DESC";
+        set_attr(layer_node, "sort-by", str);
+    }
+
     auto&& buffer_size = lyr.buffer_size();
     if (buffer_size || explicit_defaults)
     {
