@@ -34,8 +34,8 @@ void text_placements::add_expressions(expression_set& output) const
 }
 
 text_placement_info::text_placement_info(text_placements const* parent, double scale_factor_)
-    : properties(parent->defaults)
-    , scale_factor(scale_factor_)
+    : properties(parent->defaults),
+      scale_factor(scale_factor_)
 {}
 
 } // namespace mapnik
