@@ -51,7 +51,7 @@ void registry::register_name(std::string name, from_xml_function_ptr ptr, bool o
 text_placements_ptr
   registry::from_xml(std::string name, xml_node const& xml, fontset_map const& fontsets, bool is_shield)
 {
-    const auto itr = map_.find(name);
+    auto const itr = map_.find(name);
     if (itr == map_.end())
         throw config_error("Unknown placement-type '" + name + "'", xml);
     return itr->second(xml, fontsets, is_shield);
