@@ -2,41 +2,26 @@
 #include "catch.hpp"
 
 #include <string>
+#include <mapnik/mapnik.hpp>
+#include <mapnik/filesystem.hpp>
 #include <mapnik/util/fs.hpp>
 #include <mapnik/datasource_cache.hpp>
-#include <boost/filesystem/convenience.hpp>
 
 #include "cleanup.hpp" // run_cleanup()
 
-std::string plugin_path;
-
-inline void set_plugin_path(Catch::ConfigData&, std::string const& _plugin_path ) {
-    plugin_path = _plugin_path;
-}
-
-std::string working_dir;
-
-inline void set_working_dir(Catch::ConfigData&, std::string const& _working_dir ) {
-    working_dir = _working_dir;
-}
-
-
-int main (int argc, char* const argv[])
+int main(int argc, char** argv)
 {
     Catch::Session session;
+    std::string plugin_path;
+    std::string working_dir;
+    auto cli =
+      session.cli() | Catch::clara::Opt(plugin_path, "plugins")["-p"]["--plugins"]("path to mapnik plugins") |
+      Catch::clara::Opt(working_dir, "working directory")["-C"]["--working-directory"]("change working directory");
 
-    auto & cli = session.cli();
-
-    cli["-p"]["--plugins"]
-        .describe("path to mapnik plugins")
-        .bind(&set_plugin_path, "plugins");
-
-    cli["-C"]["--working-directory"]
-        .describe("change working directory")
-        .bind(&set_working_dir, "working directory");
-
+    session.cli(cli);
     int result = session.applyCommandLine(argc, argv);
 
+    mapnik::setup();
     if (!plugin_path.empty())
     {
         if (!mapnik::util::exists(plugin_path))
@@ -58,7 +43,7 @@ int main (int argc, char* const argv[])
             std::clog << "Could not find " << working_dir << "\n";
             return -1;
         }
-        boost::filesystem::current_path(working_dir);
+        mapnik::fs::current_path(working_dir);
     }
 
     if (result == 0)
@@ -69,5 +54,4 @@ int main (int argc, char* const argv[])
     testing::run_cleanup();
 
     return result;
-
 }
